"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CrashPostClient = void 0;
var _common_1 = require("../common/index");
var CrashPostClient = (function () {
    function CrashPostClient(_database, _environment, _processor) {
        if (_environment === void 0) { _environment = _common_1.Environment.Node; }
        if (_processor === void 0) { _processor = ''; }
        this._database = _database;
        this._environment = _environment;
        this._processor = _processor;
        this._processorApiClient = new _common_1.BugSplatApiClient("https://" + this._database + ".bugsplat.com", this._environment);
        this._s3ApiClient = new _common_1.S3ApiClient();
    }
    CrashPostClient.prototype.postCrash = function (application, version, type, file, md5) {
        if (md5 === void 0) { md5 = ''; }
        return __awaiter(this, void 0, void 0, function () {
            var uploadUrl;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4, this.getCrashUploadUrl(this._database, application, version, file.size)];
                    case 1:
                        uploadUrl = _a.sent();
                        return [4, this._s3ApiClient.uploadFileToPresignedUrl(uploadUrl, file)];
                    case 2:
                        _a.sent();
                        return [2, this.commitS3CrashUpload(uploadUrl, this._database, application, version, type, md5, this._processor)];
                }
            });
        });
    };
    CrashPostClient.prototype.getCrashUploadUrl = function (database, application, version, size) {
        return __awaiter(this, void 0, void 0, function () {
            var route, response, json;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        route = 'api/getCrashUploadUrl'
                            + ("?database=" + database)
                            + ("&appName=" + application)
                            + ("&appVersion=" + version)
                            + ("&crashPostSize=" + size);
                        return [4, this._processorApiClient.fetch(route)];
                    case 1:
                        response = _a.sent();
                        if (response.status === 429) {
                            throw new Error('Failed to get crash upload URL, too many requests');
                        }
                        if (response.status !== 200) {
                            throw new Error('Failed to get crash upload URL');
                        }
                        return [4, response.json()];
                    case 2:
                        json = _a.sent();
                        return [2, json.url];
                }
            });
        });
    };
    CrashPostClient.prototype.commitS3CrashUpload = function (s3Key, database, application, version, crashType, md5, processor) {
        return __awaiter(this, void 0, void 0, function () {
            var route, formData, init;
            return __generator(this, function (_a) {
                route = '/api/commitS3CrashUpload';
                formData = this._processorApiClient.createFormData();
                formData.append('database', database);
                formData.append('appName', application);
                formData.append('appVersion', version);
                formData.append('crashType', crashType);
                formData.append('s3key', s3Key);
                formData.append('md5', md5);
                if (processor) {
                    formData.append('processor', processor);
                }
                init = {
                    method: 'POST',
                    body: formData,
                    cache: 'no-cache',
                    redirect: 'follow'
                };
                return [2, this._processorApiClient.fetch(route, init)];
            });
        });
    };
    return CrashPostClient;
}());
exports.CrashPostClient = CrashPostClient;
//# sourceMappingURL=crash-post-client.js.map