import { bugsplatAppHostUrl } from '../../index';
export class OAuthClientCredentialsClient {
    _clientId;
    _clientSecret;
    _host;
    _accessToken = '';
    _tokenType = '';
    _createFormData = () => new FormData();
    _fetch = globalThis.fetch;
    constructor(_clientId, _clientSecret, _host = bugsplatAppHostUrl) {
        this._clientId = _clientId;
        this._clientSecret = _clientSecret;
        this._host = _host;
    }
    static async createAuthenticatedClient(clientId, clientSecret, host = bugsplatAppHostUrl) {
        const client = new OAuthClientCredentialsClient(clientId, clientSecret, host);
        await client.login();
        return client;
    }
    async login() {
        const url = `${this._host}/oauth2/authorize`;
        const method = 'POST';
        const body = this.createFormData();
        body.append('grant_type', 'client_credentials');
        body.append('client_id', this._clientId);
        body.append('client_secret', this._clientSecret);
        body.append('scope', 'restricted');
        const request = {
            method,
            body
        };
        const response = await this.fetch(url, request);
        const responseJson = await response.json();
        const status = response.status;
        if (responseJson.error === 'invalid_client') {
            throw new Error('Could not authenticate, check credentials and try again');
        }
        this._accessToken = responseJson.access_token;
        this._tokenType = responseJson.token_type;
        const json = async () => responseJson;
        return {
            status,
            json
        };
    }
    createFormData() {
        return this._createFormData();
    }
    async fetch(route, init) {
        const url = new URL(route, this._host);
        init = init ?? {};
        if (!init.headers) {
            init.headers = {};
        }
        init.headers['Authorization'] = `${this._tokenType} ${this._accessToken}`;
        const response = await this._fetch(url.href, init);
        if (response.status === 401) {
            throw new Error('Could not authenticate, check credentials and try again');
        }
        return response;
    }
}
//# sourceMappingURL=oauth-client-credentials-api-client.js.map