import { TableDataFormDataBuilder } from '../table-data-form-data-builder/table-data-form-data-builder';
export class TableDataClient {
    _apiClient;
    _url;
    constructor(_apiClient, _url) {
        this._apiClient = _apiClient;
        this._url = _url;
    }
    async postGetData(request) {
        const factory = () => this._apiClient.createFormData();
        const formData = new TableDataFormDataBuilder(factory)
            .withDatabase(request.database)
            .withFilterGroups(request.filterGroups)
            .withColumnGroups(request.columnGroups)
            .withPage(request.page)
            .withPageSize(request.pageSize)
            .withSortColumn(request.sortColumn)
            .withSortOrder(request.sortOrder)
            .build();
        const init = {
            method: 'POST',
            body: formData,
            cache: 'no-cache',
            credentials: 'include',
            redirect: 'follow'
        };
        return this.makeRequest(this._url, init);
    }
    async getData(request) {
        const factory = () => this._apiClient.createFormData();
        const formData = new TableDataFormDataBuilder(factory)
            .withDatabase(request.database)
            .withFilterGroups(request.filterGroups)
            .withColumnGroups(request.columnGroups)
            .withPage(request.page)
            .withPageSize(request.pageSize)
            .withSortColumn(request.sortColumn)
            .withSortOrder(request.sortOrder)
            .entries();
        const init = {
            method: 'GET',
            cache: 'no-cache',
            credentials: 'include',
            redirect: 'follow'
        };
        const queryParams = new URLSearchParams(formData).toString();
        return this.makeRequest(`${this._url}?${queryParams}`, init);
    }
    async makeRequest(url, init) {
        const response = await this._apiClient.fetch(url, init);
        const responseData = await response.json();
        const rows = responseData ? responseData[0]?.Rows : [];
        const pageData = responseData ? responseData[0]?.PageData : {};
        const status = response.status;
        const json = async () => ({ rows, pageData });
        return {
            status,
            json
        };
    }
}
//# sourceMappingURL=table-data-client.js.map